/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.server.schema.bootstrap;


import java.util.ArrayList;
import javax.naming.NamingException;

import org.apache.directory.shared.ldap.schema.*;
import org.apache.directory.server.schema.registries.*;


/**
 * A producer of schema attributeType definations for the apachemeta schema.  This
 * code has been automatically generated using schema files in the OpenLDAP
 * format along with the directory plugin for maven.  This has been done
 * to facilitate Eve<->OpenLDAP schema interoperability.
 *
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev$
 */
public class ApachemetaAttributeTypeProducer extends AbstractBootstrapProducer
{

    public ApachemetaAttributeTypeProducer()
    {
        super( ProducerTypeEnum.ATTRIBUTE_TYPE_PRODUCER );
    }


    // ------------------------------------------------------------------------
    // BootstrapProducer Methods
    // ------------------------------------------------------------------------


    /**
     * @see BootstrapProducer#produce( Registries, ProducerCallback )
     */
    public void produce( Registries registries, ProducerCallback cb )
        throws NamingException
    {
        ArrayList<String> names = new ArrayList<String>();
        BootstrapAttributeType attributeType;

        
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.1 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.1", registries );
        attributeType.setDescription( "The Object Identifier" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "objectIdentifierMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.18060.0.4.0.0.2" );
        names.clear();
        names.add( "m-oid" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.1", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.2 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.2", registries );
        attributeType.setDescription( "The Object name" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( 1024 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "caseIgnoreMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.18060.0.4.0.0.6" );
        names.clear();
        names.add( "m-name" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.2", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.3 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.3", registries );
        attributeType.setDescription( "meta descriptive information" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( 1024 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "caseIgnoreMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.15" );
        names.clear();
        names.add( "m-description" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.3", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.4 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.4", registries );
        attributeType.setDescription( "The type is obsolete" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "booleanMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.7" );
        names.clear();
        names.add( "m-obsolete" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.4", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.5 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.5", registries );
        attributeType.setDescription( "The list of superiors" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "nameOrNumericIdMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-supObjectClass" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.5", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.6 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.6", registries );
        attributeType.setDescription( "The list of mandatory ATs" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "nameOrNumericIdMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-must" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.6", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.7 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.7", registries );
        attributeType.setDescription( "The list of authorized ATs" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "nameOrNumericIdMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-may" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.7", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.8 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.8", registries );
        attributeType.setDescription( "The objectclass type" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "objectClassTypeMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.18060.0.4.0.0.1" );
        names.clear();
        names.add( "m-typeObjectClass" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.8", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.10 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.10", registries );
        attributeType.setDescription( "The list of superior" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "nameOrNumericIdMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-supAttributeType" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.10", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.11 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.11", registries );
        attributeType.setDescription( "Equality matching rule" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "nameOrNumericIdMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-equality" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.11", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.12 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.12", registries );
        attributeType.setDescription( "Ordering matching rule" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "nameOrNumericIdMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-ordering" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.12", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.13 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.13", registries );
        attributeType.setDescription( "Substring matching rule" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "nameOrNumericIdMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-substr" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.13", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.14 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.14", registries );
        attributeType.setDescription( "The syntax OID for attributeTypes and matchingRules" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "nameOrNumericIdMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.18060.0.4.0.0.2" );
        names.clear();
        names.add( "m-syntax" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.14", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.15 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.15", registries );
        attributeType.setDescription( "The attribute is single valued" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "booleanMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.7" );
        names.clear();
        names.add( "m-singleValue" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.15", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.16 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.16", registries );
        attributeType.setDescription( "The attribute is collective" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "booleanMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.7" );
        names.clear();
        names.add( "m-collective" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.16", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.17 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.17", registries );
        attributeType.setDescription( "The attribute is protected" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "booleanMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.7" );
        names.clear();
        names.add( "m-noUserModification" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.17", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.18 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.18", registries );
        attributeType.setDescription( "Usage type of an attributeType" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "caseIgnoreMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.26" );
        names.clear();
        names.add( "m-usage" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.18", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.20 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.20", registries );
        attributeType.setDescription( "The rule ID" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "ruleIDMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.18060.0.4.0.0.4" );
        names.clear();
        names.add( "m-ruleId" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.20", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.21 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.21", registries );
        attributeType.setDescription( "The name form associated with this DITStructure rule" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "caseIgnoreMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-form" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.21", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.22 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.22", registries );
        attributeType.setDescription( "The list of superiors" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "supDITStructureRuleMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.36" );
        names.clear();
        names.add( "m-supDITStructureRule" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.22", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.24 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.24", registries );
        attributeType.setDescription( "The structural ObjectClass" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "numericOidMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-oc" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.24", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.26 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.26", registries );
        attributeType.setDescription( "List of auxiliary ObjectClasses" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "numericOidMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-aux" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.26", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.27 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.27", registries );
        attributeType.setDescription( "List of precluded attribute types" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "numericOidMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-not" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.27", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.29 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.29", registries );
        attributeType.setDescription( "List of attribute types the matching rule applies to" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "numericOidMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.38" );
        names.clear();
        names.add( "m-applies" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.29", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.31 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.31", registries );
        attributeType.setDescription( "The matchingRule attribute syntax " );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "numericOidMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.18060.0.4.0.0.2" );
        names.clear();
        names.add( "m-matchingRuleSyntax" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.31", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.32 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.32", registries );
        attributeType.setDescription( "The fully qualified class name of a code based schema entity" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "caseExactMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.26" );
        names.clear();
        names.add( "m-fqcn" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.32", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.33 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.33", registries );
        attributeType.setDescription( "The Java bytecode for a code based schema entity" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.5" );
        names.clear();
        names.add( "m-bytecode" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.33", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.34 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.34", registries );
        attributeType.setDescription( "whether or not a syntax is human readable" );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "booleanMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.7" );
        names.clear();
        names.add( "x-humanReadable" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.34", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.37 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.37", registries );
        attributeType.setDescription( "Used as a marker for schemas to enable or disable them." );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "booleanMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.7" );
        names.clear();
        names.add( "m-disabled" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.37", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.38 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.38", registries );
        attributeType.setDescription( "The dependencies of a schema: other schema names." );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( false );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "caseIgnoreMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.1466.115.121.1.15" );
        names.clear();
        names.add( "m-dependencies" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.38", attributeType );

 
        // --------------------------------------------------------------------
        // AttributeType 1.3.6.1.4.1.18060.0.4.0.2.39 
        // --------------------------------------------------------------------

        attributeType = newAttributeType( "1.3.6.1.4.1.18060.0.4.0.2.39", registries );
        attributeType.setDescription( "The maximum length for an attribute value." );
        attributeType.setCanUserModify( ! false );
        attributeType.setSingleValue( true );
        attributeType.setCollective( false );
        attributeType.setObsolete( false );
        attributeType.setLength( -1 );
        attributeType.setUsage( UsageEnum.getUsage( "USER_APPLICATIONS" ) );
        attributeType.setEqualityId( "caseIgnoreMatch" );
        attributeType.setSyntaxId( "1.3.6.1.4.1.18060.0.4.0.0.4" );
        names.clear();
        names.add( "m-length" );
        attributeType.setNames( names.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.18060.0.4.0.2.39", attributeType );

    }
}
